/***************************************************************************
                          pictureplugin.h  -  description
                             -------------------
    begin                : Son Apr 14 2002
    copyright            : (C) 2002 by Dominik Seichter
    email                : domseichter@web.de
 ***************************************************************************/

/***************************************************************************
 *                                                                         *
 *   This program is free software; you can redistribute it and/or modify  *
 *   it under the terms of the GNU General Public License as published by  *
 *   the Free Software Foundation; either version 2 of the License, or     *
 *   (at your option) any later version.                                   *
 *                                                                         *
 ***************************************************************************/

#ifndef PICTUREPLUGIN_H
#define PICTUREPLUGIN_H

#include "batchrenamer.h"
#include "pluginloader.h"
#include "fileplugin.h"

class TQVBoxLayout;
class TQHBoxLayout;
class TQString;
class TQWidget;
class PicturePlugin : public FilePlugin  {
    TQ_OBJECT
  
    public:
        PicturePlugin();
    
        const TQString getName() const;
        const TQString getAccelName() const;
        const TQString getPattern() const;
        TQString processFile( BatchRenamer* b, int i, TQString token, int );
};

#endif
